@@ -8,12 +8,10 @@ CIJ_TEST_NAME=$(basename "${BASH_SOURCE[0]}")
 export CIJ_TEST_NAME
 # shellcheck source=modules/cijoe.sh
 source "$CIJ_ROOT/modules/cijoe.sh"
-test::enter
+test.enter
 
-: "${XNVME_URI:?Must be set and non-empty}"
-
-if ! ssh::cmd "lblk enum"; then
-  test::fail
+if ! cij.cmd "lblk enum"; then
+  test.fail
 fi
 
-test::pass
+test.pass
